@@ -3,13 +3,12 @@
 #include <qpainter.h>
 #include <qcolor.h>
 #include <qpixmap.h>
-#include <kstring.h>
 
 class Jewel{
   friend class Playfield;
   friend class Previewfield;
  public:
-  Jewel(const short parts, const short maxcol,const QString *b);
+  Jewel(const short parts, const short maxcol);
   const Jewel &operator=(const Jewel &);
   short x(),y();
   void newJewel();
@@ -24,7 +23,7 @@ class Jewel{
     xp++;
   };
   void step();
-  put(Playfield &);
+  void put(Playfield &);
  private:
   short xp,yp;
   short maxColors;
@@ -32,8 +31,7 @@ class Jewel{
   short *parts;
   static QColor colorList[8];
   QPixmap *jewelPixmaps[10];
-  const QString *baseDir;
-  void loadPics();
+  int loadPics();
 };
 
 #endif
