@@ -2,28 +2,29 @@
 #define KJEWEL_H
 
 #include <playfield.h>
-#include <ktopwidget.h>
+#include <kmainwindow.h>
 #include <kmenubar.h>
-#include <kconfig.h>
-//#include <kkeydialog.h>
-//#include <kaccel.h>
 #include <klocale.h>
 #include <kapp.h>
 
-#define VERSION "0.9"
-#define DATE "6.1.1999"
-class KJewelMainWidget: public KTopLevelWidget{
+#define VERSION "0.91"
+#define DATE "19.05.2002"
+class KJewelMainWindow: public KMainWindow{
   Q_OBJECT
 
   public:
-    /**
-     * The constructor method for class KJewelMainWidget
-     */
-    KJewelMainWidget(KApplication *app);
-    /**
-      * The destructor method for class KJewelMainWidget
-      */
-    Playfield *playfield;
+  /**
+   * The constructor method for class KJewelMainWidget
+   */
+  KJewelMainWindow(const char *name, KApplication *a);
+  /**
+   * The destructor method for class KJewelMainWidget
+   */
+  virtual ~KJewelMainWindow();
+  void closeEvent(QCloseEvent *);
+
+  Playfield *playfield;
+
   protected:
     void keyPressEvent(QKeyEvent *e);
     protected slots:
@@ -33,9 +34,7 @@ class KJewelMainWidget: public KTopLevelWidget{
 	 */
 	void quitapp() ;
   private:
-    KConfig *config;
     void helpmenu();
-//    KAccel *accel;
     void createMenu();
     KMenuBar *menu;
     QPopupMenu *file, *options, *help;
